var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import React, { useMemo } from 'react';
import PropTypes from 'prop-types';
import { css } from '@leafygreen-ui/emotion';
// Import from core so we can register the appropriate languages ourselves
import hljs from 'highlight.js/lib/core';
import hljsDefineGraphQL from 'highlightjs-graphql';
import CodeWrapper from './CodeWrapper';
import { Variant, Language } from './types';
import { SupportedLanguages, languageParsers } from './languages';
import { injectGlobalStyles } from './globalStyles';
import renderingPlugin from './renderingPlugin';
function filterSupportedLanguages(language) {
    return language !== 'cs' && language !== 'js' && language !== 'ts';
}
var syntaxHighlightingInitialized = false;
function initializeSyntaxHighlighting() {
    syntaxHighlightingInitialized = true;
    injectGlobalStyles();
    // We filter out 'cs' here because it's redundant with 'csharp' and 'js' because it's redundant with 'javascript'
    var SupportedLanguagesList = Object.values(SupportedLanguages).filter(filterSupportedLanguages);
    SupportedLanguagesList.forEach(function (language) {
        if (language === 'graphql') {
            hljsDefineGraphQL(hljs);
        }
        else {
            hljs.registerLanguage(language, languageParsers[language]);
        }
    });
    hljs.configure({
        languages: SupportedLanguagesList,
        classPrefix: 'lg-highlight-',
        tabReplace: '  ',
    });
    hljs.addPlugin(renderingPlugin);
}
function Syntax(_a) {
    var children = _a.children, language = _a.language, _b = _a.variant, variant = _b === void 0 ? Variant.Light : _b, _c = _a.showLineNumbers, showLineNumbers = _c === void 0 ? false : _c, rest = __rest(_a, ["children", "language", "variant", "showLineNumbers"]);
    if (!syntaxHighlightingInitialized) {
        initializeSyntaxHighlighting();
    }
    var codeWrapperSharedProps = __assign({ language: language, variant: variant }, rest);
    var highlightedContent = useMemo(function () {
        if (language === Language.None) {
            return null;
        }
        return hljs.highlight(language, children);
    }, [language, children]);
    if (highlightedContent === null) {
        return React.createElement(CodeWrapper, __assign({}, codeWrapperSharedProps), children);
    }
    if (showLineNumbers) {
        return (React.createElement(CodeWrapper, __assign({}, codeWrapperSharedProps),
            React.createElement("table", { className: css(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n            border-spacing: 0;\n          "], ["\n            border-spacing: 0;\n          "]))) },
                React.createElement("tbody", null, highlightedContent.reactWithNumbers))));
    }
    return (React.createElement(CodeWrapper, __assign({}, codeWrapperSharedProps), highlightedContent.react));
}
Syntax.displayName = 'Syntax';
Syntax.propTypes = {
    children: PropTypes.string.isRequired,
    lang: PropTypes.oneOf(Object.values(Language)),
    className: PropTypes.string,
    variant: PropTypes.oneOf(Object.values(Variant)),
};
export default Syntax;
var templateObject_1;
//# sourceMappingURL=Syntax.js.map