var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import React from 'react';
import { css, cx } from '@leafygreen-ui/emotion';
import { createDataProp } from '@leafygreen-ui/lib';
function Token(_a) {
    var kind = _a.kind, children = _a.children;
    var className = kind ? "lg-highlight-" + kind : '';
    return React.createElement("span", { className: className }, children);
}
function isArray(item) {
    return item != null && item instanceof Array;
}
function isObject(item) {
    return item != null && typeof item === 'object' && !(item instanceof Array);
}
function isString(item) {
    return item != null && typeof item === 'string';
}
export function processToken(token, key) {
    if (token == null) {
        return null;
    }
    if (isString(token)) {
        return token;
    }
    if (isArray(token)) {
        return token.map(processToken);
    }
    if (isObject(token)) {
        return (React.createElement(Token, { key: key, kind: token.kind }, processToken(token.children)));
    }
    return token;
}
var cellStyle = css(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n  user-select: none;\n  border-spacing: 0;\n  padding: 0;\n  vertical-align: top;\n"], ["\n  user-select: none;\n  border-spacing: 0;\n  padding: 0;\n  vertical-align: top;\n"])));
export var numberCellDataProp = createDataProp('code-number-cell');
export function LineTableRow(_a) {
    var lineNumber = _a.lineNumber, children = _a.children;
    var numberCellStyle = css(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n    padding-right: 24px;\n  "], ["\n    padding-right: 24px;\n  "])));
    return (React.createElement("tr", null,
        React.createElement("td", __assign({}, numberCellDataProp.prop, { className: cx(cellStyle, numberCellStyle) }), lineNumber),
        React.createElement("td", { className: cellStyle }, children)));
}
export function treeToLines(children) {
    var lines = [];
    var currentLineIndex = 0;
    // Create a new line, if no lines exist yet
    if (lines[currentLineIndex] == null) {
        lines[currentLineIndex] = [];
    }
    children.forEach(function (child) {
        if (isString(child)) {
            // If the current element is a string that includes a line break, we need to handle it differently
            if (child.includes('\n')) {
                child.split('').forEach(function (fragment) {
                    if (fragment === '\n') {
                        // If the fragment is a new line character, we create a new line
                        currentLineIndex++;
                        lines[currentLineIndex] = [];
                    }
                    else {
                        var currentIndexInLine = lines[currentLineIndex].length - 1;
                        if (isString(lines[currentLineIndex][currentIndexInLine])) {
                            // If the last element in the line is a string, we append this string to it
                            lines[currentLineIndex][currentIndexInLine] += fragment;
                        }
                        else {
                            // Otherwise, we push the string fragment on its own
                            lines[currentLineIndex].push(fragment);
                        }
                    }
                });
            }
            else {
                // We don't need to do anything special in the case where the string doesn't contain a line break
                lines[currentLineIndex].push(child);
            }
        }
        // Line breaks aren't a part of token objects, so we can assume those objects go on the current line
        if (isObject(child)) {
            lines[currentLineIndex].push(child);
        }
    });
    // Strip empty lines from the beginning of code blocks
    while (lines[0].length === 0) {
        lines.shift();
    }
    // Strip empty lines from the end of code blocks
    while (lines[lines.length - 1].length === 0) {
        lines.pop();
    }
    return lines;
}
function TableRowLine(_a) {
    var lineNumber = _a.lineNumber, line = _a.line;
    return (React.createElement(LineTableRow, { lineNumber: lineNumber }, line.map(processToken)));
}
function TableRowFragment(_a) {
    var line = _a.line;
    return (React.createElement(React.Fragment, null,
        React.createElement("span", null, line.map(processToken)),
        '\n'));
}
var plugin = {
    'after:highlight': function (result) {
        var rootNode = result.emitter.rootNode;
        var lines = treeToLines(rootNode.children);
        result.react = [];
        result.reactWithNumbers = [];
        lines.forEach(function (line, index) {
            result.react.push(React.createElement(TableRowFragment, { key: index, line: line }));
            result.reactWithNumbers.push(React.createElement(TableRowLine, { key: index, lineNumber: index + 1, line: line }));
        });
    },
};
export default plugin;
var templateObject_1, templateObject_2;
//# sourceMappingURL=renderingPlugin.js.map