/// <reference types="react" />
export declare const Variant: {
    readonly Light: "light";
    readonly Dark: "dark";
};
export declare type Variant = typeof Variant[keyof typeof Variant];
export declare const Language: {
    readonly None: "none";
    readonly JavaScript: "javascript";
    readonly JS: "js";
    readonly TypeScript: "typescript";
    readonly TS: "ts";
    readonly Csharp: "csharp";
    readonly Cs: "cs";
    readonly CLike: "clike";
    readonly Go: "go";
    readonly Ini: "ini";
    readonly Java: "java";
    readonly Perl: "perl";
    readonly Php: "php";
    readonly Python: "python";
    readonly Ruby: "ruby";
    readonly Rust: "rust";
    readonly Scala: "scala";
    readonly Swift: "swift";
    readonly Kotlin: "kotlin";
    readonly ObjectiveC: "objectivec";
    readonly Bash: "bash";
    readonly Shell: "shell";
    readonly Sql: "sql";
    readonly Yaml: "yaml";
    readonly Json: "json";
    readonly Graphql: "graphql";
    readonly Diff: "diff";
};
export declare type Language = typeof Language[keyof typeof Language];
export interface SyntaxProps extends React.HTMLAttributes<HTMLElement> {
    /**
     * The children to render inside Code. This is usually going to be a formatted code block or line.
     */
    children: string;
    /**
     * An additional CSS class applied to the root element
     */
    className?: string;
    /**
     * The language to highlight the syntax of.
     */
    language: Language;
    /**
     * The variant for the syntax-highlighted block.
     *
     * default: `'light'`
     */
    variant?: Variant;
    /**
     * Shows line numbers. This is specifically used for the Code component implementation.
     *
     * default: `'false'`
     */
    showLineNumbers?: boolean;
}
//# sourceMappingURL=types.d.ts.map